@@ -1,8 +1,16 @@
 # Copyright(c) 2014, The LIMIX developers (Christoph Lippert, Paolo Francesco Casale, Oliver Stegle)
-# All rights reserved.
 #
-# LIMIX is provided under a 2-clause BSD license.
-# See license.txt for the complete license.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import scipy as sp 
 import limix.io.data_util as du
@@ -195,7 +203,7 @@ class genotype_reader_h5py():
             else:
                 return  sp.arange(self.geno_matrix.shape[1])
 
-    def getPos(selfidx_start=None,idx_end=None,pos_start=None,pos_end=None,chrom=None,pos_cum_start=None,pos_cum_end=None):
+    def getPos(self,idx_start=None,idx_end=None,pos_start=None,pos_end=None,chrom=None,pos_cum_start=None,pos_cum_end=None):
         """
         get the positions of the genotypes
 
@@ -207,11 +215,11 @@ class genotype_reader_h5py():
         if (idx_start is None) and (idx_end is None) and ((pos_start is not None) & (pos_end is not None) & (chrom is not None)) or ((pos_cum_start is not None) & (pos_cum_end is not None)):
             idx_start,idx_end=self.getGenoIndex(pos_start=pos_start,pos_end=pos_end,chrom=chrom,pos_cum_start=pos_cum_start,pos_cum_end=pose_cum1)
         if (idx_start is not None) & (idx_end is not None):
-            return self.geno_chrom[idx_start:idx_end],self.geno_pos[idx_start:idx_end]
+            return self.position.iloc[idx_start:idx_end]
         elif snp_idx is not None:
-            return self.geno_chrom[snp_idx],self.geno_pos[snp_idx]            
+            return self.position.iloc[snp_idx]
         else:
-            return self.geno_chrom,self.geno_pos
+            return self.position
 
 
     def getIcis_geno(self,geneID,cis_window=50E3):
@@ -414,7 +422,7 @@ class genotype_reader_tables():
             else:
                 return  sp.arange(self.geno_matrix.shape[1])
 
-    def getPos(selfidx_start=None,idx_end=None,pos_start=None,pos_end=None,chrom=None,windowsize=0):
+    def getPos(self,idx_start=None,idx_end=None,snp_idx=None,pos_start=None,pos_end=None,chrom=None,windowsize=0):
         """
         get the positions of the genotypes
 
@@ -426,11 +434,11 @@ class genotype_reader_tables():
         if (idx_start is None) and (idx_end is None) and ((pos_start is not None) & (pos_end is not None) ) or (chrom is not None):
             idx_start,idx_end=self.getGenoIndex(pos_start=pos_start,pos_end=pos_end,chrom=chrom,windowsize=windowsize)
         if (idx_start is not None) & (idx_end is not None):
-            return self.geno_chrom[idx_start:idx_end],self.geno_pos[idx_start:idx_end]
+            return self.position.iloc[idx_start:idx_end]
         elif snp_idx is not None:
-            return self.geno_chrom[snp_idx],self.geno_pos[snp_idx]            
+            return self.position.iloc[snp_idx]
         else:
-            return self.geno_chrom,self.geno_pos
+            return self.position
 
 
 """
