@@ -38,8 +38,8 @@ def PC_varExplained(Y,standardized=True):
         Y-=Y.mean(0)
         Y/=Y.std(0)
     covY = sp.cov(Y)
-    S,U = LA.eigh(covY+1e-6*sp.eye(covY.shape[0]))
+    S,U = linalg.eigh(covY+1e-6*sp.eye(covY.shape[0]))
     S = S[::-1]
     rv = sp.array([S[0:i].sum() for i in range(1,S.shape[0])])
     rv/= S.sum()
-    return rv
\ No newline at end of file
+    return rv
